# Merge SCOPUS and PubMed searches, then sample cases

# -- Load data -- #

pmc <- read.csv( file.path( intdir, "PubMed_cleaned.csv" ) )
scopus <- read.csv( file.path( datadir, "DatabaseSearches", "20160123_ScopusSearch_Emergencias.csv" ) )

# -- Clean and append -- #

# Clean PubMed searches
pmc$match <- (pmc$match_100pct | pmc$match_0pct)
pmc$database <- "PubMed"
# Add in Scopus searches (5 Emergencias articles)
colnames( scopus ) <- tolower( colnames( scopus ) )
colnames( scopus )[colnames( scopus )=="title"] <- "name"
colnames( scopus )[colnames( scopus )=="source.title"] <- "journal"
scopus$database <- "Scopus"
scopus$match <- grepl( "100[%]", scopus$abstract )
articleDF <-gtools::smartbind( pmc, scopus[ , colnames(scopus) %in% colnames(pmc) ] )

save( articleDF, file = file.path( intdir, "combinedSearch.Rdata" ) )
write.csv( articleDF[,cn], file = file.path( intdir, "combinedSearch.csv" ), row.names = FALSE )

# -- Sample -- #

articleDFonlyMatches <- articleDF[ articleDF$match & is.na( articleDF$exclusion ),] # potential cases
nPotentialCases <- nrow( articleDFonlyMatches )
nSampledCases <- floor( nrow( articleDFonlyMatches ) / 2 )
set.seed( 5733925 )
sampIdx <- sample.int( n = nPotentialCases, size = nSampledCases, replace = FALSE )
articleDFsample <- articleDFonlyMatches[ sampIdx, ]
save( articleDFsample, file = file.path( intdir, "sampledCases.Rdata" ) )
write.csv( articleDFsample, file = file.path( intdir, "sampledCases.csv" ), row.names = FALSE )

# -- Match sampled cases to controls -- #

articleDFnoMatches <- articleDF[ !articleDF$match & is.na( articleDF$exclusion ),] # potential controls


matched <- matchit( match ~ year + journal, data = rbind( articleDFnoMatches, articleDFsample )[,c("journal","match","year")], method = "exact" )


articleDFsample <- articleDFsample %>% group_by( journal, year ) %>% mutate( i = seq( n() ), id = paste0( year, gsub(" *", "", journal), i ) )
articleDFcontrol %>% group_by( journal, year ) %>% summarise( n = n() )
if( any( articleDFcontrol$n==0 ) | any( articleDFsample$n==0 ) ) stop()





ddply( articleDFsample, .( journal, year ), function( dat, articleDF ) {
  dat[]
}, articleDF = articleDF )

# -- Export final results -- #

save( nSampledCases, nPotentialCases, sampIdx, file = file.path( intdir, "FinalResults_cleanPubMed" ) )
